@@ -42,9 +42,11 @@ class MiSiC():
     #     return stitch_tiles(yp,yp)
 
     def segment(self,im,invert = False,exclude = 16):        
-        sh = self.shapeindex_preprocess(im)        
-        sh = -sh if invert else sh
-        tiles,params = extract_tiles(sh,size = self.size,exclude = exclude)               
+        #sh = self.shapeindex_preprocess(im)        
+        #sh = -sh if invert else sh
+        tiles,params = extract_tiles(im[:,:,np.newaxis],size = self.size,exclude = exclude)               
+        tiles = np.array([self.shapeindex_preprocess(normalize2max(t))  for t in tiles[:,:,:,0]])
+        tiles = -tiles if invert else tiles
         yp = self.model.predict(tiles)
         return stitch_tiles(yp,params)
 
